#
# spec file for package smooth
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _uver   0_9
%define _lver   0.9
%define sover   0
Name:           smooth
Version:        0.9.10
Release:        1.4
Summary:        C++ class library for widgets, IO, XML and more
License:        Artistic-2.0
URL:            http://www.smooth-project.org
Source0:        https://sourceforge.net/projects/smooth/files/smooth/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(fribidi) >= 1.0.12
BuildRequires:  pkgconfig(gtk+-3.0)
# Upstream use pkgconfig(libcpuid) >= 0.6.2
BuildRequires:  pkgconfig(libcpuid) >= 0.6.0
BuildRequires:  pkgconfig(libcurl) >= 7.87.0
BuildRequires:  pkgconfig(libjpeg)
# Upstream use pkgconfig(libxml-2.0) >= 2.10.3
BuildRequires:  pkgconfig(libxml-2.0) >= 2.9.14

%description
smooth is an object oriented C++ class library. It provides basic
functionality and platform support for applications and libraries.

Features provided by smooth include:

  * user interface API with various widgets
  * multithreading API
  * file and network IO interface
  * transparent Unicode and software internationalization support
  * a libxml2-based XML parser

%package        devel
Summary:        Development files for %{name}
Requires:       lib%{name}-%{_uver}-%{sover} = %{version}
Requires:       pkgconfig(x11)

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package     -n lib%{name}-%{_uver}-%{sover}
Summary:        C++ class library for widgets, IO, XML and more

%description -n lib%{name}-%{_uver}-%{sover}
smooth is an object oriented C++ class library. It provides basic
functionality and platform support for applications and libraries.

Features provided by smooth include:

  * user interface API with various widgets
  * multithreading API
  * file and network IO interface
  * transparent Unicode and software internationalization support
  * a libxml2-based XML parser

%prep
%autosetup -p1
dos2unix Copying Readme.md

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
%make_build config=systemlibcpuid

%install
%make_install libdir=%{_libdir} includedir=%{_includedir} bindir=%{_bindir}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n lib%{name}-%{_uver}-%{sover} -p /sbin/ldconfig
%postun -n lib%{name}-%{_uver}-%{sover} -p /sbin/ldconfig

%files
%license Copying
%doc ChangeLog Readme.md
%{_bindir}/%{name}-translator

%files devel
%doc ChangeLog Readme.md
%license Copying
%{_includedir}/%{name}
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}-%{_lver}.so

%files -n lib%{name}-%{_uver}-%{sover}
%license Copying
%{_libdir}/lib%{name}-%{_lver}.so.%{sover}

%changelog
* Fri Jun 23 2023 ecsos <ecsos@opensuse.org>
- Update to 0.9.10
  - windowgdi.cpp
  - apply dark mode to top window edge too on Windows 10 and 11
  - fontcairo.cpp
  - respect text scaling factor in addition to font size setting
  - surfacecairo.cpp
  - attempt to read desktop scale factor from KDE settings if GDK query fails
  - backendxlib.cpp
  - added support for KDE color schemes (including dark mode)
  - windowxlib.cpp
  - improved compatibility of drag & drop implementation with KDE running under Wayland
  - fixed focus handling for windows without window manager decorations
  - surfacecocoa.mm
  - fixed crash trying to draw to windows before they are fully constructed
  - application.cpp
  - fixed determination of application path when running under Rosetta
  - listbox.cpp
  - fixed and improved list entry dragging behavior
  - http.cpp
  - fixed libcurl proxy feature detection
  - cpu.cpp
  - fixed number of cores reported for CPUs with different core types (performance/efficiency)
  - fixed number of cores reported for SMP systems (now reporting total number of cores)
  - instream.cpp
  - allow data pointer to be NULL in InputData if number of bytes is 0
  - outstream.cpp
  - allow data pointer to be NULL in OutputData if number of bytes is 0
  - various minor performance optimizations
  - fixed long paths being converted to 8.3 format on recent versions of Windows
  - fixed handling of long UNC paths on Windows
  - upgraded fribidi to version 1.0.12
  - upgraded libcpuid to version 0.6.2
  - upgraded libxml2 to version 2.10.3
  - upgraded libcurl to version 7.87.0
  - upgraded libiconv to version 1.17
  - upgraded libpng to version 1.6.39
  - upgraded libwebp to version 1.3.0
  - upgraded zlib to version 1.2.13
* Wed Jun 22 2022 ecsos <ecsos@opensuse.org>
- Update to 0.9.9
  - instream.cpp
  - prevent opening folders with file IO classes
  - abort InputLine call when encoutering NUL bytes
  - datetime.cpp
  - fixed potential crash upon failed time conversion
  - filedlg_cocoa.mm
  - fixed incompatibility with macOS 12.0 Monterey
  - dirdlg_win32.cpp
  - prepend a newline to caption for improved layout
  - added support for building Windows ARM64 binaries
  - upgraded fribidi to version 1.0.11
  - upgraded libcpuid to version 0.5.1
  - upgraded libxml2 to version 2.9.12
  - upgraded libjpeg to version 9e
- Changes from 0.9.8
  - imageloader.cpp
  - added support for auto-detecting image formats
  - webp.cpp
  - added support for WebP image decoding
  - windowgdi.cpp
  - improved scaling when setting icons via SetIcon()
  - init.cpp
  - warn about incomplete application shutdown in debug builds
  - thread.cpp
  - made it illegal to call Stop on the current thread
  - fixed thread synchronization issues in wait and exit functions
  - array.cpp
  - fixed thread synchronization issues when accessing arrays
  - rwlock.cpp
  - fixed thread synchronization issues
  - combobox.cpp
  - fixed dropdown staying open when parent window moves or resizes
  - popupmenu.cpp
  - fixed popup staying open when parent window moves or resizes
  - popupmenuentry.cpp
  - fixed occasional crashes when opening third level popup menus
  - backendxlib.cpp
  - fixed timers being invoked in GTK threads despite denyTimerInterrupts state
  - backendcocoa.mm
  - fixed possible crash when quitting applications through a dock command
  - surfacecocoa.mm
  - fixed rendering of bitmaps with alpha channel
  - surfacecairo.cpp
  - fixed drawing of diagonal lines when running in a Wayland session
  - respect custom DPI settings on Xfce desktop
  - windowxlib.cpp
  - fixed possible crash on exit when running in a Wayland session
  - fixed drag & drop working unreliably
  - fixed incorrect usage of XGetInputFocus API
  - application.cpp
  - fixed determination of binary path on FreeBSD
  - file.cpp
  - fixed accessing files via file:// URLs
  - fixed several instances of undefined behavior found with -fsanitize=undefined
  - fixed translation field not being focused after selecting entries in Translator utility
  - upgraded libcurl to version 7.77.0
* Tue Apr 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.7
  * screenxlib.cpp: improved multi-monitor support for X11 based
    systems
  * backendxlib.cpp: fixed issues querying GTK theme colors
  * window.cpp: fixed drawing issues on KDE systems
  * arrows.cpp: fixed unintentional wrap-around when going below
    zero value
  * cursor.cpp: avoid sending two onInput signals when replacing
    selected text
  * semaphoreposix.cpp: use custom semaphore implementation
    based on condition variable
  * implemented alpha-blending for drawing bitmaps with alpha
    channel
* Thu Jan  7 2021 ecsos <ecsos@opensuse.org>
- Update to 0.9.6
  - surfacegdi.cpp
  - fixed too high DPI values being reported
  - surfacegdiplus.cpp
  - fixed too high DPI values being reported
  - windowcocoa.mm
  - fixed glitches after closing tabs in tabbed mode
  - menubar_cocoa.mm
  - fixed possible crash after menubar contents change
  - droptarget.cpp
  - fixed rare crash related to drag & drop handling
  - translator.cpp
  - also look for translations in application data folder
  - tree.cpp
  - improved rendering of tree widget in scaled mode
  - http.cpp
  - include status code in response header fields
  - implemented proper multi-monitor support for macOS
  - added support for macOS 11.0 Big Sur
  - added a separate error code for denied access to file IO drivers
  - fixed wrong color space returned in BitmapBackend::GetPixel for multiple backends
  - upgraded fribidi to version 1.0.10
* Wed Jul 15 2020 Jan Engelhardt <jengelh@inai.de>
- Show feature list with bullet points. Trim conjecture.
* Wed Jul  1 2020 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v0.9.5)
